OC.L10N.register(
    "core",
    {
    "Please select a file." : "יש לבחור קובץ.",
    "File is too big" : "הקובץ גדול מדי",
    "The selected file is not an image." : "הקובץ שנבחר אינו קובץ תמונה",
    "The selected file cannot be read." : "לא ניתן לקרוא את הקובץ שנבחר",
    "The file was uploaded" : "הקובץ הועלה",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "הקובץ שהועלה חורג מההנחיה upload_max_filesize ב־php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "הקובץ שהועלה חורג מההנחיה MAX_FILE_SIZE שצוינה בטופס ה־HTML",
    "The file was only partially uploaded" : "הקובץ הועלה באופן חלקי בלבד",
    "No file was uploaded" : "לא הועלה קובץ",
    "Missing a temporary folder" : "חסרה תיקייה זמנית",
    "Could not write file to disk" : "לא ניתן לכתוב לכונן",
    "A PHP extension stopped the file upload" : "הרחבת PHP עצרה את העלאת הקובץ",
    "Invalid file provided" : "סופק קובץ לא חוקי",
    "No image or file provided" : "לא סופקו תמונה או קובץ",
    "Unknown filetype" : "סוג קובץ לא מוכר",
    "An error occurred. Please contact your admin." : "אירעה שגיאה. יש ליצור קשר עם המנהל שלך.",
    "Invalid image" : "תמונה לא חוקית",
    "No temporary profile picture available, try again" : "לא קיימת תמונת פרופיל זמנית, יש לנסות שוב",
    "No crop data provided" : "לא סופק מידע קיטום",
    "No valid crop data provided" : "לא סופק מידע קיטום חוקי",
    "Crop is not square" : "הקיטום אינו מרובע",
    "State token does not match" : "קוד אימות מצב אינו תואם",
    "Invalid app password" : "ססמת היישומון שגויה",
    "Could not complete login" : "לא ניתן להשלים את הכניסה",
    "Your login token is invalid or has expired" : "אסימון הכניסה שלך שגוי או שהוא פג",
    "Login" : "כניסה",
    "Password reset is disabled" : "אין אפשרות לאפס ססמה",
    "%s password reset" : "%s הסיסמא אופסה",
    "Password reset" : "איפוס ססמה",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "לחיצה על הכפתור הבא תוביל לאיפוס הססמה, אם לא ביקשת לאפס ססמה יש להתעלם מהודעה זו",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "יש ללחוץ על הקישור הבא כדי לאפס ססמה, אם לא ביקשת לאפס ססמה יש להתעלם מהודעה זו",
    "Reset your password" : "איפוס הססמה שלך",
    "Internal error" : "שגיאה פנימית",
    "Nextcloud Server" : "שרת Nextcloud",
    "Some of your link shares have been removed" : "חלק מקישורי השיתופים שלך הוסרו",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "עקב תקלת אבטחה נאלצנו להסיר חלק מקישורי השיתופים שלך. נא להיכנס לקישור לקבלת פרטים נוספים.",
    "Learn more ↗" : "מידע נוסף ↖ ",
    "Preparing update" : "מכין עדכון",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "שלב בתיקון:",
    "Repair info:" : "פרטי תיקון:",
    "Repair warning:" : "אזהרת תיקון:",
    "Repair error:" : "שגיאת תיקון:",
    "Turned on maintenance mode" : "הפעלת מצב אחזקה",
    "Turned off maintenance mode" : "כיבוי מצב אחזקה",
    "Maintenance mode is kept active" : "מצב אחזקה נשמר פעיל",
    "Updating database schema" : "עדכון סכימת מסד נתונים",
    "Updated database" : "עדכון מסד נתונים",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "בודק אם סכימת מסד הנתונים עבור %s ניתנת לעדכון (פעולה זו יכולה להמשך זמן רב תלוי בגודל מסד הנתונים)",
    "Updated \"%1$s\" to %2$s" : "„%1$s” עודכן לכדי %2$s",
    "Set log level to debug" : "קביעת רמת דיווח לתהליך ניפוי בשגיאות",
    "Reset log level" : "קביעה מחדש לרמת דיווח",
    "Starting code integrity check" : "התחלת בדיקת תקינות קוד",
    "Finished code integrity check" : "סיום בדיקת תקינות קוד",
    "%s (incompatible)" : "%s (לא תואם)",
    "The following apps have been disabled: %s" : "היישומים הבאים הושבתו: %s",
    "Already up to date" : "כבר עדכני",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "שרת האינטרנט לא מוגדר עדיין כראוי כדי לאפשר סנכרון קבצים, כיוון שמנשק ה־WebDAV כנראה אינו מתפקד.",
    "Error occurred while checking server setup" : "שגיאה אירעה בזמן בדיקת התקנת השרת",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "כותרת ה־HTTP‏ „{header}” אינה מוגדרת לערך „{expected}”. מדובר בפרצת אבטחה או פרטיות, מומלץ להתאים את ההגדרה הזאת בהתאם.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "כותרת ה־HTTP‏ „{header}” אינה מוגדרת לערך „{expected}”. יתכן שחלק מהתכונות לא תעבודנה כראוי, מומלץ להתאים את ההגדרה הזאת בהתאם.",
    "unknown text" : "מלל לא מוכר",
    "Hello world!" : "שלום עולם!",
    "sunny" : "שמשי",
    "Hello {name}, the weather is {weather}" : "שלום {name}, מזג האוויר הנו {weather}",
    "Hello {name}" : "שלום {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>אלו תוצאות החיפוש שלך<script>alert(1)</script></strong>",
    "new" : "חדש",
    "_download %n file_::_download %n files_" : ["התקבל קובץ %n","התקבלו %n קבצים","התקבלו %n קבצים"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "העדכון מתבצע, יציאה מהעמוד הזה עשויה להפריע לתהליך בסביבות מסוימות.",
    "Update to {version}" : "עדכון ל־{version}",
    "An error occurred." : "אירעה שגיאה.",
    "Please reload the page." : "יש להעלות מחדש דף זה.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "העדכון לא בוצע בהצלחה. למידע נוסף <a href=\"{url}\">ניתן לבדוק בהודעת הפורום שלנו</a> המכסה נושא זו.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "העדכון לא הצליח. נא לדווח על התקלה הזאת ל<a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">קהילת Nextcloud</a>.",
    "More apps" : "יישומים נוספים",
    "Log in" : "כניסה",
    "Logging in …" : "מתבצעת כניסה…",
    "Server side authentication failed!" : "אימות לצד שרת נכשל!",
    "Please contact your administrator." : "יש ליצור קשר עם המנהל.",
    "An internal error occurred." : "אירעה שגיאה פנימית.",
    "Please try again or contact your administrator." : "יש לנסות שוב ליצור קשר עם המנהל שלך.",
    "Password" : "ססמה",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "זיהינו מספר ניסיונות כניסה שגויים מכתובת ה־IP שלך. לכן, ניסיון הכניסה הבא יתאפשר עבורך רק בעוד 30 שניות.",
    "Log in with a device" : "כניסה עם מכשיר",
    "Your account is not setup for passwordless login." : "החשבון שלך לא מוגדר לכניסה בלי ססמה.",
    "Passwordless authentication is not supported in your browser." : "אימות ללא ססמה אינו נתמך על ידי הדפדפן שלך.",
    "Passwordless authentication is only available over a secure connection." : "אימות ללא ססמה זמין רק דרך חיבור מאובטח.",
    "Reset password" : "איפוס ססמה",
    "Couldn't send reset email. Please contact your administrator." : "לא ניתן היה לשלוח דואר אלקטרוני לאיפוס. יש לפנות למנהל שלך.",
    "Back to login" : "חזרה לכניסה",
    "New password" : "ססמה חדשה",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "הקבצים שלך מוצפנים. לא תהיה שום דרך להחזיר את הנתונים לאחר איפוס הסיסמה. אם אינך בטוח מה לעשות, פנה למנהל המערכת לפני שתמשיך. האם אתה באמת רוצה להמשיך?",
    "I know what I'm doing" : "אני יודע/ת מה אני עושה",
    "Resetting password" : "איפוס ססמה",
    "Recommended apps" : "יישומונים מומלצים",
    "Loading apps …" : "היישומונים נטענים…",
    "Installing apps …" : "היישומונים מותקנים…",
    "App download or installation failed" : "הורדת או התקנת היישומון נכשלה",
    "Skip" : "דלג",
    "Install recommended apps" : "התקנת יישומונים מומלצים",
    "Schedule work & meetings, synced with all your devices." : "תזמון עבודה ופגישות בסנכרון עם כל המכשירים שלך.",
    "Keep your colleagues and friends in one place without leaking their private info." : "עמיתים לעבודה וחברים מרוכזים במקום אחד מבלי זליגה של הפרטים האישיים שלהם.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "יישומון דוא״ל פשוט שמשתלב בצורה נחמדה עם הקבצים, אנשי הקשר והיומן.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "צ'אטים, שיחות וידאו, שיתוף מסך, פגישות מקוונות ועידת אינטרנט - בדפדפן ובאפליקציות סלולריות.",
    "Reset search" : "איפוס החיפוש",
    "Search contacts …" : "חיפוש אנשי קשר…",
    "Could not load your contacts" : "לא ניתן לטעון את אנשי הקשר שלך",
    "No contacts found" : "לא נמצאו אנשי קשר",
    "Install the Contacts app" : "התקנת יישומון אנשי הקשר",
    "Loading your contacts …" : "אנשי הקשר שלך נטענים…",
    "Looking for {term} …" : "מתבצע חיפוש אחר {term}…",
    "Search for {name} only" : "חפש ל-{name} בלבד",
    "Start typing to search" : "להתחלת החיפוש יש להקליד",
    "Loading more results …" : "נטענות תוצאות נוספות…",
    "Load more results" : "לטעון עוד תוצאות",
    "Search" : "חיפוש",
    "No results for {query}" : "אין תוצאות עבור {query}",
    "An error occurred while searching for {type}" : "אירעה שגיאה בחיפוש אחר {type}",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["נא להקליד לפחות תו אחד כדי לחפש","נא להקליד לפחות {minSearchLength} תווים כדי לחפש","נא להקליד לפחות {minSearchLength} תווים כדי לחפש","נא להקליד לפחות {minSearchLength} תווים כדי לחפש"],
    "Forgot password?" : "שכחת ססמה?",
    "Back" : "חזרה",
    "Search {types} …" : "חפש {types} ...",
    "Date" : "תאריך",
    "Today" : "היום",
    "Last year" : "שנה שעברה",
    "Not found" : "לא נמצא",
    "Searching …" : "מתבצע חיפוש…",
    "Settings menu" : "תפריט הגדרות",
    "No" : "לא",
    "Yes" : "כן",
    "Choose" : "בחירה",
    "Copy" : "העתקה",
    "Move" : "העברה",
    "OK" : "אישור",
    "Error loading message template: {error}" : "שגיאה בטעינת תבנית ההודעות: {error}",
    "read-only" : "לקריאה בלבד",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} הנגשות קובץ","{count} התנגשויות קבצים","{count} התנגשויות קבצים","{count} התנגשויות קבצים"],
    "One file conflict" : "התנגשות קובץ אחת",
    "New Files" : "קבצים חדשים",
    "Already existing files" : "קבצים קיימים כבר",
    "Which files do you want to keep?" : "אילו קבצים ברצונך לשמור?",
    "If you select both versions, the copied file will have a number added to its name." : "אם תבחר האפשרות לשמור את שתי הגרסאות, לשם קובץ המועתק יתווסף מספר.",
    "Cancel" : "ביטול",
    "Continue" : "המשך",
    "(all selected)" : "(הכול נבחר)",
    "({count} selected)" : "({count} נבחרו)",
    "Error loading file exists template" : "שגיאה בטעינת קובץ תבנית קיימים",
    "Saving …" : "מתבצעת שמירה…",
    "seconds ago" : "לפני מספר שניות",
    "Connection to server lost" : "החיבור לשרת אבד",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["תקלה בטעינת העמוד, יתבצע רענון בעוד שנייה","תקלה בטעינת העמוד, יתבצע רענון בעוד %n שניות","תקלה בטעינת העמוד, יתבצע רענון בעוד %n שניות","תקלה בטעינת העמוד, יתבצע רענון בעוד %n שניות"],
    "Add to a project" : "הוספה למיזם",
    "Show details" : "הצגת פרטים",
    "Hide details" : "הסתרת פרטים",
    "Rename project" : "שינוי שם מיזם",
    "Failed to rename the project" : "שינוי שם המיזם נכשל",
    "Failed to create a project" : "יצירת המיזם נכשלה",
    "Failed to add the item to the project" : "הוספת פריט למיזם נכשלה",
    "Connect items to a project to make them easier to find" : "יש לחבר פריטים למיזם כדי להקל על איתורם",
    "Type to search for existing projects" : "לחיפוש במיזמים הקיימים יש להקליד",
    "New in" : "חדש ב־",
    "View changelog" : "הצגת יומן שינויים",
    "Very weak password" : "ססמה מאוד חלשה",
    "Weak password" : "ססמה חלשה",
    "So-so password" : "ססמה בינונית",
    "Good password" : "ססמה טובה",
    "Strong password" : "ססמה חזקה",
    "No action available" : "אין פעולה זמינה",
    "Error fetching contact actions" : "שגיאה בקבלת פעולות אנשי הקשר",
    "Non-existing tag #{tag}" : "תגית לא קיימת #{tag}",
    "Restricted" : "מוגבלת",
    "Invisible" : "נסתרת",
    "Delete" : "מחיקה",
    "Rename" : "שינוי שם",
    "Collaborative tags" : "תגיות שיתופיות",
    "No tags found" : "לא נמצאו תגים",
    "Personal" : "אישי",
    "Apps" : "יישומים",
    "Admin" : "מנהל",
    "Help" : "עזרה",
    "Access forbidden" : "הגישה נחסמה",
    "Back to %s" : "חזרה אל %s",
    "Page not found" : "העמוד לא נמצא",
    "Too many requests" : "יותר מדי בקשות",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "היו יותר מדי בקשות מהרשת שלך. נסה שוב מאוחר יותר, או צור קשר עם מנהל המערכת שלך אם זו שגיאה.",
    "Error" : "שגיאה",
    "Previous" : "הקודם",
    "Internal Server Error" : "שגיאה פנימית בשרת",
    "The server was unable to complete your request." : "השרת לא הצליח להשלים את הבקשה שלך.",
    "If this happens again, please send the technical details below to the server administrator." : "אם דבר כזה קורה שוב, נא לשלוח את הפרטים הטכניים שלהלן למנהל השרת.",
    "More details can be found in the server log." : "פרטים נוספים ניתן למצוא בלוג של הרשת.",
    "Technical details" : "פרטים טכנים",
    "Remote Address: %s" : "כתובת מרוחקת: %s",
    "Request ID: %s" : "מספר זיהוי מבוקש: %s",
    "Type: %s" : "סוג: %s",
    "Code: %s" : "קוד: %s",
    "Message: %s" : "הודעה: %s",
    "File: %s" : "קובץ: %s",
    "Line: %s" : "שורה: %s",
    "Trace" : "עקבות",
    "Security warning" : "אזהרת אבטחה",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "תיקיות וקובצי הנתונים שלך כנראה נגישים מהאינטרנט מכיוון שקובץ ה־‎.htaccess לא עובד.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "למידע בנוגע להגדרת השרת שלך כראוי, נא לעיין ב<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">תיעוד</a>.",
    "Create an <strong>admin account</strong>" : "יצירת <strong>חשבון מנהל</strong>",
    "Show password" : "הצגת ססמה",
    "Storage & database" : "אחסון ומסד נתונים",
    "Data folder" : "תיקיית נתונים",
    "Configure the database" : "הגדרת מסד הנתונים",
    "Only %s is available." : "רק %s זמין.",
    "Install and activate additional PHP modules to choose other database types." : "לבחירת סוגים אחרים של מסדי נתונים יש להתקין ולהפעיל מודולי PHP נוספים.",
    "For more details check out the documentation." : "למידע נוסף יש לבדוק במסמכי התיעוד.",
    "Database password" : "ססמת מסד הנתונים",
    "Database name" : "שם מסד הנתונים",
    "Database tablespace" : "מרחב הכתובות של מסד הנתונים",
    "Database host" : "שרת מסד נתונים",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "נא לציין את מספר הפתחה יחד עם שם המארח (למשל: localhost:5432).",
    "Performance warning" : "אזהרת ביצועים",
    "You chose SQLite as database." : "בחרת ב־SQLite כמסד נתונים.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "יש להשתמש ב־SQLite לסביבות מזעריות או למטרות פיתוח. בסביבת פעילות שגרתית אנו ממליצים על מנגנון מסד נתונים אחר.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "אם יש לך לקוח שמשמש אותך לסנכרון קבצים, השימוש ב־SQLite לא מומלץ עבורך.",
    "Install" : "התקנה",
    "Need help?" : "עזרה נזקקת?",
    "See the documentation" : "יש לצפות במסמכי התיעוד",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "נראה שאתה מנסה להתקין מחדש את ה-Nextcloud שלך.אבל הקובץ CAN_INSTALL חסר בספריית ה-config שלך. אנא צור את הקובץ CAN_INSTALL בתיקיית ה-config שלך כדי להמשיך.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "לא ניתן להסיר את CAN_INSTALL מתיקיית ההגדרות. נא להסיר את הקובץ הזה ידנית.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "יישום זה דורש JavaScript לפעולה נכונה. יש {linkstart}לאפשר JavaScript{linkend} ולטעון את העמוד מחדש.",
    "Skip to main content" : "דילוג לתוכן הראשי",
    "Skip to navigation of app" : "דילוג לניווט של היישומון",
    "Go to %s" : "מעבר אל %s",
    "Get your own free account" : "קבלת חשבון משלך בחינם",
    "Connect to your account" : "התחברות לחשבון שלך",
    "Please log in before granting %1$s access to your %2$s account." : "נא להיכנס בטרם הענקת גישה לחשבון שלך ב־%2$s לטובת %1$s.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "אם אינך מנסה להגדיר מכשיר חדש או אפליקציה חדשה, מישהו מנסה לרמות אותך להעניק לו גישה לנתונים שלך. במקרה הזה, אל תמשיך, ובמקום זאת פנה למנהל המערכת שלך.",
    "Grant access" : "הענקת גישה",
    "Account access" : "גישה לחשבון",
    "You are about to grant %1$s access to your %2$s account." : "פעולה זו תעניק ל־%1$s גישה לחשבון ה־%2$s שלך.",
    "Account connected" : "חשבון מחובר",
    "Your client should now be connected!" : "הלקוח שלך אמור להיות מחובר עכשיו!",
    "You can close this window." : "ניתן לסגור את החלון הזה.",
    "This share is password-protected" : "שיתוף זה מוגן בססמה",
    "Email address" : "כתובת דוא״ל",
    "Two-factor authentication" : "אימות דו־שלבי",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "על החשבון שלך מופעלת אבטחה מוגברת. נא לבחור גורם אימות נוסף:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "לא ניתן לטעון לפחות את אחד משיטות האימות הדו־שלבי שהפעלת. נא ליצור קשר עם מנהל המערכת.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "אימות דו־שלבי נאכף אך הוא אינו מוגדר על החשבון שלך. נא ליצור קשר עם המנהל שלך לקבלת עזרה.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "אימות דו-גורמי נאכף, אך לא הוגדר בחשבון שלך. אנא תמשיך להגדיר אימות דו-גורמי.",
    "Set up two-factor authentication" : "הגדרת אימות דו־שלבי",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "אימות דו־שלבי נאכף אך הוא אינו מוגדר על החשבון שלך. נא להשתמש באחד מהקודים לצורכי גיבוי כדי להיכנס או ליצור קשר עם המנהל שלך לקבלת עזרה.",
    "Use backup code" : "שימוש בקוד גיבוי",
    "Cancel login" : "ביטול התחברות",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "על החשבון שלך נאכפת אבטחה מורחבת. נא לבחור איזה ספק להגדיר:",
    "Error while validating your second factor" : "שגיאה בעת אימות הגורם השני",
    "Access through untrusted domain" : "גישה דרך שם מתחם בלתי מהימן",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "נא ליצור קשר עם מנהל השרת שלך. אם הרשאות ניהול השרת הן בידיך, יש לערוך את ההגדרה „trusted_domains” בתוך config/config.php כמו הדוגמה שבתוך ",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "ניתן למצוא מידע נוסף על אופן ההגדרה של התכונה הזאת ב%1$sתיעוד%2$s.",
    "App update required" : "נדרש עדכון יישום",
    "%1$s will be updated to version %2$s" : "%1$s יעודכן לגרסה %2$s",
    "The following apps will be updated:" : "היישומונים הבאים יעודכנו:",
    "These incompatible apps will be disabled:" : "יישומים לא תואמים ינוטרלו:",
    "The theme %s has been disabled." : "ערכת הנושא %s הושבתה.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "יש לוודא שמסד הנתונים, תיקיית config ותיקיית data גובו לפני המשך התהליך.",
    "Start update" : "התחלת עדכון",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "למניעת פסקי זמן בהתקנות גדולות, ניתן במקום להריץ את הפקודה הבאה בתיקיית ההתקנה שלך:",
    "Detailed logs" : "יומן מפורט",
    "Update needed" : "עדכון נדרש",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "לעזרה יש לעיין ב<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">תיעוד</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "ידוע לי שאם אמשיך דרך מנשק הדפדפן אהיה חשוף לסכנה, שהבקשה עשויה להיקלע לחוסר מענה וכתוצאה מכך אבדן נתונים, אך יש לי גיבוי וידוע לי איך לשחזר את העותק שלי במקרה של כשל.",
    "Upgrade via web on my own risk" : "השדרוג דרך האינטרנט הוא על אחריותי",
    "Maintenance mode" : "מצב תחזוקה",
    "This %s instance is currently in maintenance mode, which may take a while." : "עותק %s זה כרגע במצב תחזוקה, שיארך זמן מה.",
    "This page will refresh itself when the instance is available again." : "עמוד זה ירענן את עצמו כאשר העותק ישוב להיות זמין.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "יש ליצור קשר עם מנהל המערכת אם הודעה שו נמשכת או מופיעה באופן בלתי צפוי. ",
    "The user limit of this instance is reached." : "מגבלת המשתמשים של מופע זה הושגה.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "מסתבר כי PHP לא מוגדר כראוי כדי לתשאל משתני סביבה. הבדיקה עם getenv(\"PATH\") מחזירה תשובה ריקה בלבד.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "הופעלה תצורה לקריאה בלבד. מצב זה מונע את הגדרת חלק מההגדרות דרך מנשק דפדפן. יתרה מכך, יש להפוך את הקובץ למורשה לכתיבה ידנית בכל עדכון מחדש.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "מסד הנתונים שלך לא עובד עם רמת הפרדת פעולות של „READ COMMITTED” . מצב כזה יכול לגרום לבעיות כאשר מספר פעולות רצות במקביל.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "מודול ה־PHP בשם „fileinfo” חסר. מומלץ בחום להפעיל את המודול הזה כדי לקבל את התוצאות הטובות ביותר בזיהוי סוג MIME.",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "לא ניתן היה להפעיל את משימות ה־cron דרך שורת פקודה. השגיאות הטכניות הבאות התרחשו:",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "פונקציית ה־PHP‏ „set_time_limit” אינה זמינה. מצב זה עשוי לגרום לעצירת סקריפטים באמצע הפעולה ולפגיעה בהתקנה שלך. אנו ממליצים בחום להפעיל את הפונקציה הזאת.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "ל־PHP שלך אין תמיכה ב־FreeType. מצב כזה יגרום לתמונות פרופיל משובשות לצד מנשק הגדרות משובש.",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "חסר אינדקס „{indexName}” בטבלה „{tableName}”.",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "למסד הנתונים חסרים אינדקסים. כיוון שהוספת אינדקסים על טבלאות גדולות היא פעולה שגוזלת זמן רב הם לא נוספים אוטומטית. על ידי הרצת הפקודה „occ db:add-missing-indices” האינדקסים החסרים נוספים ידנית ללא עצירת פעולת העותק. לאחר הוספת האינדקסים השאילתות על הטבלאות האלה מהירות בהרבה.",
    "Missing primary key on table \"{tableName}\"." : "חסר מפתח ראשי בטבלה \"{tableName}\".",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "במסד הנתונים חסרים כמה מפתחות ראשיים. בשל העובדה שהוספת מפתחות ראשיים לטבלאות גדולות עשויה להימשך זמן מה, הם לא נוספו אוטומטית. על ידי הפעלת \"occ db: add-missing-primary-keys\", ניתן להוסיף מפתחות הראשיים החסרים האלה באופן ידני, בזמן שהמופע ממשיך לפעול.",
    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "חסרה עמודה האופציונלית \"{columnName}\" בטבלה \"{tableName}\".",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "במסד הנתונים חסרים כמה עמודות אופציונליות. בשל העובדה שהוספת עמודות בטבלאות גדולות עשויה להימשך זמן מה, הן לא נוספו אוטומטית כאשר הן יכולות להיות אופציונליות. על ידי הפעלת \"occ db: add-missing-column\", ניתן להוסיף את העמודות החסרות האלה באופן ידני בזמן שהמופע ממשיך לפעול. לאחר הוספת העמודות, חלק מהתכונות עשויות לשפר את ההיענות או את השימושיות.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "במופע זה חסרים כמה מודולי PHP מומלצים. לשיפור ביצועים ותאימות טובה יותר, מומלץ להתקין אותם.",
    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "למודול php-imagick במקרה הזה אין תמיכה ב- SVG. לקבלת תאימות טובה יותר, מומלץ להתקין אותו.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite הוא מנגנון מסד הנתונים נכון לעכשיו. במערכות גדולות מוטב להחליף למנגנון מסד נתונים אחר.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "מצב זה מומלץ במיוחד כאשר מריצים את לקוח שולחן העבודה לסנכרון קבצים.",
    "The PHP memory limit is below the recommended value of 512MB." : "מגבלת הזיכרון של ה־PHP היא מתחת לערך המומלץ על סך 512 מ״ב.",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "ספריות אפליקציות מסוימות הן בבעלות משתמש אחר מזה של שרת האינטרנט. זה יכול להיות במקרה שאפליקציות הותקנו באופן ידני. בדוק את ההרשאות של ספריות האפליקציות הבאות:",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "מופע זה משתמש באיחסון אובייקטים מבוססת S3 כאחסון ראשי. הקבצים שהועלו מאוחסנים באופן זמני בשרת, ולכן מומלץ שיהיה שטח פנוי של 50 GB בספריית ה- temp של PHP. בדוק ביומנים לקבלת יותר פרטים על הנתיב והשטח הזמין. כדי לשפר זאת, אנא שנה את הספריה הזמנית ב- php.ini, או תפנה יותר מקום בנתיב זה.",
    "Account name or email" : "שם משתמש או דואר אלקטרוני",
    "Wrong username or password." : "שם המשתמש או הססמה שגויים.",
    "User disabled" : "משתמש מושבת",
    "Username or email" : "שם משתמש או דואר אלקטרוני",
    "If it is not there ask your local administrator." : "אם זה לא נמצא, שאל את המנהל המקומי שלך.",
    "Settings" : "הגדרות",
    "Show all contacts …" : "הצגת כל אנשי הקשר…",
    "No files in here" : "אין כאן קבצים",
    "New folder" : "תיקייה חדשה",
    "No more subfolders in here" : "אין כאן עוד תת־תיקיות",
    "Name" : "שם",
    "Size" : "גודל",
    "Modified" : "מועד שינוי",
    "\"{name}\" is an invalid file name." : "\"{name}\" הנו שם קובץ לא חוקי.",
    "File name cannot be empty." : "שם קובץ אינו יכול להיות ריק",
    "\"/\" is not allowed inside a file name." : "אסור להשתמש ב־„/” בתוך שם קובץ.",
    "\"{name}\" is not an allowed filetype" : "סוד הקובץ „{name}” אינו מורשה",
    "{newName} already exists" : "{newName} כבר קיים",
    "Error loading file picker template: {error}" : "שגיאה בטעינת תבנית בחירת הקבצים: {error}",
    "Pending" : "בהמתנה",
    "Home" : "בית",
    "Copy to {folder}" : "העתקה אל {folder}",
    "Move to {folder}" : "העברה אל {folder}",
    "Authentication required" : "נדרש אימות",
    "This action requires you to confirm your password" : "פעולה זו דורשת ממך לאמת את הססמה שלך",
    "Confirm" : "אימות",
    "Failed to authenticate, try again" : "האימות נכשל, נא לנסות שוב",
    "Users" : "משתמשים",
    "Username" : "שם משתמש",
    "Database user" : "שם משתמש במסד הנתונים",
    "Confirm your password" : "אימות הססמה שלך",
    "App token" : "אסימון יישום",
    "Alternative log in using app token" : "כניסה חלופית באמצעות אסימון יישומון",
    "Please use the command line updater because you have a big instance with more than 50 users." : "נא להשתמש בתכנית העדכון משורת הפקודה כיוון שיש לך עותק גדול עם למעלה מ־50 משתמשים."
},
"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
